##parameters=type,id

#PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')  + '/Data/'+ type+ '/'+ id
PATH = context.getInstancePath() + '/Data/' + type + '/' + id
Ref = context.restrictedTraverse(PATH)

cols=['column1','column2','column3','column4']

print '<font size=5> Select columns to generate table. </font> <br> <br> <br>'

print '<table width=800>'

print '<tr> <td> <b> '

for item in cols:
    print string.capitalize(item)
    print '&nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp &nbsp '    

print '</b> </td> </tr>'

print '<tr> <td>'

for nos in cols:

    print '<select class="form-element" name='
    print nos
    print '>' 
    for property in Ref.propertyIds():
       print '<option>'
       print property 
       print '</option>'  
    print '</select>'
    print '&nbsp &nbsp &nbsp'    

print '</td> </tr>'
print '</table>'

return printed
